summaryrefslogtreecommitdiffstats
path: root/packaging/windows/mingw-make.sh
diff options
context:
space:
mode:
Diffstat (limited to 'packaging/windows/mingw-make.sh')
-rwxr-xr-xpackaging/windows/mingw-make.sh15
1 files changed, 11 insertions, 4 deletions
diff --git a/packaging/windows/mingw-make.sh b/packaging/windows/mingw-make.sh
index 794a8521a..a1596fd53 100755
--- a/packaging/windows/mingw-make.sh
+++ b/packaging/windows/mingw-make.sh
@@ -5,13 +5,20 @@
#
# the paths work for the default mingw32 install on Fedora - adjust as
# necessary
# force recreation of the nsi file in order to get the correct version
# number
BASEDIR=$(dirname $0)
rm $BASEDIR/subsurface.nsi > /dev/null 2>&1
+rm $BASEDIR/../../ssrf-version.h > /dev/null 2>&1
export PATH=/usr/i686-w64-mingw32/sys-root/mingw/bin:$PATH
-mingw32-qmake-qt4 CROSS_PATH=/usr/i686-w64-mingw32/sys-root/mingw \
- LIBGIT2DEVEL=../libgit2 CONFIG+=libgit21-api $BASEDIR/../../subsurface.pro
+mingw32-qmake-qt4 \
+ CROSS_PATH=/usr/i686-w64-mingw32/sys-root/mingw \
+ LIBDCDEVEL=../libdivecomputer \
+ LIBMARBLEDEVEL=../marble \
+ LIBGIT2DEVEL=../libgit2 CONFIG+=libgit21-api \
+ $BASEDIR/../../subsurface.pro
mingw32-make $@
@@ -5,13 +5,20 @@
# the paths work for the default mingw32 install on Fedora - adjust as
# necessary
+# this assumes that local cross builds for libdivecomputer and libgit2
+# are in ../libdivecomputer and ../libgit2
-# force recreation of the nsi file in order to get the correct version
-# number
+# force recreation of the nsi file and Subsurface version header file
+# in order to get the correct version number
BASEDIR=$(dirname $0)
rm $BASEDIR/subsurface.nsi > /dev/null 2>&1